@@ -22,18 +22,33 @@ pub struct AppState {
 /// Initializes a store on disk.
 /// Creates a new agent, if neccessary.
 pub fn init(config: Config) -> BetterResult<AppState> {
+    // Check if atomic-server is already running somwehere, and try to stop it. It's not a problem if things go wrong here, so errors are simply logged.
+    let _ = crate::process::terminate_existing_processes(&config)
+        .map_err(|e| log::error!("Could not check for running instance: {}", e));
+
+    // Enable all logging
+    std::env::set_var("RUST_LOG", "info");
+    env_logger::init();
+
+    const VERSION: &str = env!("CARGO_PKG_VERSION");
+    log::info!("Atomic-server {}. Use --help for more options. Visit https://docs.atomicdata.dev and https://github.com/joepio/atomic-data-rust.", VERSION);
+
     let store = atomic_lib::Db::init(&config.store_path, config.local_base_url.clone())?;
     if config.initialize {
         log::info!("Initialize: creating and populating new Database...");
-        atomic_lib::populate::populate_default_store(&store)?;
+        atomic_lib::populate::populate_default_store(&store)
+            .map_err(|e| format!("Failed to populate default store. {}", e))?;
         // Building the index here is needed to perform TPF queries on imported resources
         store.build_index(true)?;
     }
     set_default_agent(&config, &store)?;
     if config.initialize {
-        atomic_lib::populate::populate_hierarchy(&store)?;
-        atomic_lib::populate::populate_collections(&store)?;
-        atomic_lib::populate::populate_endpoints(&store)?;
+        atomic_lib::populate::populate_hierarchy(&store)
+            .map_err(|e| format!("Failed to populate hierarchy. {}", e))?;
+        atomic_lib::populate::populate_collections(&store)
+            .map_err(|e| format!("Failed to populate collections. {}", e))?;
+        atomic_lib::populate::populate_endpoints(&store)
+            .map_err(|e| format!("Failed to populate endpoints. {}", e))?;
         set_up_initial_invite(&store)?;
         // This means that editing the .env does _not_ grant you the rights to edit the Drive.
         set_up_drive(&store)?;
@@ -128,6 +143,16 @@ fn set_up_initial_invite(store: &impl Storelike) -> BetterResult<()> {
         atomic_lib::Value::AtomicUrl(store.get_base_url().into()),
         store,
     )?;
+    invite.set_propval(
+        atomic_lib::urls::PARENT.into(),
+        atomic_lib::Value::AtomicUrl(store.get_base_url().into()),
+        store,
+    )?;
+    invite.set_propval(
+        atomic_lib::urls::NAME.into(),
+        atomic_lib::Value::String("Setup".into()),
+        store,
+    )?;
     invite.set_propval_string(
         atomic_lib::urls::DESCRIPTION.into(),
         "Use this Invite to create an Agent, or use an existing one. Accepting will grant your Agent the necessary rights to edit the data in your Atomic Server. This can only be used once. If you, for whatever reason, need a new `/setup` invite, you can pass the `--init` flag to `atomic-server`.",
